---
title: "What I want from a GLAM/Cultural Heritage Data Science Network"
description: |
    In which I set out my goals for what such a network should be aiming to achieve, and seek feedback.
slug: glam-datasci-network-what-i-want
date: 2021-01-18T17:27:00+00:00
series: glam-dsn
tags:
- Data science
- GLAM
- Librarianship
- Humanities
- Cultural heritage
---

# Introduction

[As I mentioned last year](https://erambler.co.uk/blog/ssi-fellowship/), I was awarded a Software Sustainability Institute Fellowship to pursue the project of setting up a Cultural Heritage/GLAM data science network. Obviously, the global pandemic has forced a re-think of many plans and this is no exception, so I'm coming back to reflect on it and make sure I'm clear about the core goals so that everything else still moves in the right direction.

One of the main reasons I have for setting up a GLAM data science network is because it's **something *I* want**. The advice to "scratch your own itch" is often given to people looking for an open project to start or contribute to, and the lack of a community of people with whom to learn & share ideas and practice is something that itches for me very much.

The "motivation" section in my original draft project brief for this work said:

> Cultural heritage work, like all knowledge work, is increasingly data-based, or at least gives opportunities to make use of data day-to-day. The proper skills to use this data enable more effective working. Knowledge and experience thus gained improves understanding of and empathy with users also using such skills.

But of course, I have my own reasons for wanting to do this too. In particular, I want to:

-   Advocate for the value of ethical, sustainable data science across a wide range of roles within the British Library and the wider sector
-   Advance the sector to make the best use of data and digital sources in the most ethical and sustainable way possible
-   Understand how and why people use data from the British Library, and plan/deliver better services to support that
-   Keep up to date with relevant developments in data science
-   Learn from others' skills and experiences, and share my own in turn

Those initial goals imply some further supporting goals:

-   Build up the confidence of colleagues who might benefit from data science skills but don't feel they are "technical" or "computer literate" enough
-   Further to that, build up a base of colleagues with the confidence to share their skills & knowledge with others, whether through teaching, giving talks, writing or other channels
-   Identify common awareness gaps (skills/knowledge that people don't know they're missing) and address them
-   Develop a communal space (primarily online) in which people feel safe to ask questions
-   Develop a body of professional practice and help colleagues to learn and contribute to the evolution of this, including practices of data ethics, software engineering, statistics, high performance computing, &#x2026;
-   Break down language barriers between data scientists and others

I'll expand on this separately as my planning develops, but here are a few specific activities that I'd like to be able to do to support this:

-   Organise less-formal learning and sharing events to complement the more formal training already available within organisations and the wider sector, including "show and tell" sessions, panel discussions, code cafés, masterclasses, guest speakers, reading/study groups, co-working sessions, &#x2026;
-   Organise training to cover intermediate skills and knowledge currently missing from the available options, including the awareness gaps and professional practice mentioned above
-   Collect together links to other relevant resources to support self-led learning


# Decisions to be made

There are all sorts of open questions in my head about this right now, but here are some of the key ones.


## Is it GLAM or Cultural Heritage?

When I first started planning this whole thing, I went with "Cultural Heritage", since I was pretty transparently targeting my own organisation. The  British Library is fairly unequivocally a CH organisation. But as I've gone along I've found myself gravitating more towards the term "GLAM" (which [stands for Galleries, Libraries, Archives, Museums](https://en.wikipedia.org/wiki/GLAM_(industry))) as it covers a similar range of work but is clearer (when you spell out the acronym) about what kinds of work are included.


## What skills are relevant?

This turns out to be surprisingly important, at least in terms of how the community is described, as they define the boundaries of the community and can be the difference between someone feeling welcome or excluded. For example, I think that some introductory statistics training would be immensely valuable for anyone working with data to understand what options are open to them and what limitations those options have, but is the word "statistics" offputting *per se* to those who've chosen a career in arts & humanities? I don't know because I don't have that background and perspective.


## Keep it internal to the BL, or open up early on?

I originally planned to focus primarily on my own organisation to start with, feeling that it would be easier to organise events and build a network within a single organisation. However, the pandemic has changed my thinking significantly. Firstly, it's now impossible to organise in-person events and that will continue for quite some time to come, so there is less need to focus on the logistics of getting people into the same room. Secondly, people within the sector are much more used to attending remote events, which can easily be opened up to multiple organisations in many countries, timezones allowing. It now makes more sense to focus primarily on *online* activities, which opens up the possibility of building a critical mass of active participants much more quickly by opening up to the wider sector.


# Conclusion

This is the type of post that I could let run and run without ever actually publishing, but since it's something I *need* feedback and opinions on from other people, I'd better ship it! I really want to know what you think about this, whether you feel it's relevant to you and what would make it useful. Comments are open below, or you can contact me via [Mastodon](https://scholar.social/@petrichor) or [Twitter](https://twitter.com/jezcope).
